/************************************************************************
 *
 *  MathMLConverter.java
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright: 2002-2003 by Henrik Just
 *
 *  All Rights Reserved.
 * 
 *  Version 0.3.1 (2003-12-02)
 *
 */

package writer2latex.xhtml;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;

import writer2latex.office.*;

public class MathMLConverter {

    private boolean bSupportMathML;
	
    public MathMLConverter(boolean bSupportMathML) {
        this.bSupportMathML = bSupportMathML;
    }
	
    public void convert(Node onode, Node hnode) {
        if (bSupportMathML) {
            convertNode(onode,hnode);
        }
        else {
            Document htmlDOM = hnode.getOwnerDocument();
            NodeList annotationList
                = ((Element) onode).getElementsByTagName(XMLString.MATH_ANNOTATION);
            if (annotationList.getLength()>0 && annotationList.item(0).hasChildNodes()) {
                // Insert the StarMath annotation as a kbd element
                Element kbd = htmlDOM.createElement("kbd");
                hnode.appendChild(kbd);
                NodeList list = annotationList.item(0).getChildNodes();
                int nLen = list.getLength();
                for (int i=0; i<nLen; i++) {
                    Node child = list.item(i);
                    if (child.getNodeType()==Node.TEXT_NODE) {
                        kbd.appendChild(htmlDOM.createTextNode(child.getNodeValue()));
                    }
                }
            }
            else {
                hnode.appendChild(htmlDOM.createTextNode("[Warning: formula ignored]"));
            }
        }
    }

    public void convertNode(Node onode, Node hnode) {
        if (onode.getNodeType()==Node.ELEMENT_NODE) {
            if (onode.getNodeName().equals(XMLString.MATH_SEMANTICS)) {
                // ignore this construction
                convertNodeList(onode.getChildNodes(),hnode);
            }
            else if (onode.getNodeName().equals(XMLString.MATH_ANNOTATION)) {
                // ignore the annotation (StarMath) completely
                // (mozilla renders it for some reason)
            }
            else {
                String sElementName = stripNamespace(onode.getNodeName());
                Element newNode = hnode.getOwnerDocument().createElement(sElementName);
                hnode.appendChild(newNode);
                if (onode.hasAttributes()) {
                    NamedNodeMap attr = onode.getAttributes();
                    int nLen = attr.getLength();
                    for (int i=0; i<nLen; i++) {
                        String sName = attr.item(i).getNodeName();
                        if (sName.equals("xmlns:math")) { sName="xmlns"; }
                        else { sName = stripNamespace(sName); }
                        String sValue = attr.item(i).getNodeValue();
                        newNode.setAttribute(sName,sValue);
                    }
                }            
                convertNodeList(onode.getChildNodes(),newNode);
            }
        }
        else if (onode.getNodeType()==Node.TEXT_NODE) {
            hnode.appendChild(hnode.getOwnerDocument().createTextNode(onode.getNodeValue()));
        }
    }
	
    private void convertNodeList(NodeList list, Node hnode) {
        if (list==null) { return; }
        int nLen = list.getLength();
        for (int i=0; i<nLen; i++) {
            convertNode(list.item(i),hnode);
        }
    }
	
    private String stripNamespace(String s) {
        int nPos = s.indexOf(':');
        return s.substring(nPos+1);
    }

}